#
# spec file for package giada
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org/
#

Name:           giada
Version:        0.13.0
Release:        1.2
Summary:        Sampler Audio Tool
License:        GPL-3.0+
Group:          Productivity/Multimedia/Sound/Utilities
Url:            http://giadamusic.com
Source0:        https://github.com/monocasual/giada/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        giada.svg
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  make
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  fltk-devel
BuildRequires:  portaudio-devel
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(jansson) >= 2.7
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libpulse-simple)
BuildRequires:  pkgconfig(rtmidi) >= 2.1.0
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xpm)
BuildRequires:  pkgconfig(xext)
BuildRequires:  hicolor-icon-theme
BuildRequires:  update-desktop-files
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Giada is a minimal, hardcore audio tool for DJs and live performers. Load or
record up to 32 samples, choose to play them in single mode (drum machine) or
loop mode (sequencer), and start the show with your computer keyboard as a
controller.

%prep
%setup -q

# Do not compile in DATE and TIME
BUILDDATE=$(LC_ALL=C date -ur %{_sourcedir}/%{name}.changes +'%b %d %Y')
sed -i "s/__DATE__/\"$BUILDDATE\"/" $(grep -rl '__DATE__') || :

%if 0%{?suse_version} <= 1320
sed -i 's/\-Wno-error=misleading-indentation//' $(grep -rl misleading-indentation)
%endif

%build
./autogen.sh
%configure --target=linux
make %{?_smp_mflags} \
    CFLAGS="$CFLAGS -fPIC"
    
%install
make DESTDIR=%{buildroot} install

install -Dm 0644 %{SOURCE1} %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%suse_update_desktop_file -c %{name} %{name} "Sampler Audio Tool" %{name} %{name} AudioVideo Audio Sequencer

%post
%icon_theme_cache_post
%desktop_database_post

%postun
%icon_theme_cache_postun
%desktop_database_postun

%files
%defattr(-,root,root)
%doc COPYING ChangeLog
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg

%changelog
* Sat Oct 22 2016 avvissu@yandex.by
- Update to 0.13.0:
  * see: /usr/share/doc/packages/giada/ChangeLog
- Fix compilation errors on GCC 6
* Fri Jun 17 2016 avvissu@yandex.by
- Update to 0.12.2:
  * see: /usr/share/doc/packages/giada/ChangeLog
- Fix build on openSUSE > 13.2 (use a supported version of GCC)
* Wed Jan 27 2016 avvissu@yandex.ru
- Update to 0.11.2:
  * see: /usr/share/doc/packages/giada/ChangeLog
* Fri Dec 25 2015 avvissu@yandex.ru
- Update to 0.11.1:
  * see: /usr/share/doc/packages/giada/ChangeLog
* Sun Dec  6 2015 avvissu@yandex.ru
- Update to 0.11.0:
  * see: /usr/share/doc/packages/giada/ChangeLog
- Add BuildRequires: pkgconfig(jansson)
* Wed Oct 21 2015 avvissu@yandex.ru
- Update to 0.10.2:
  * see: /usr/share/doc/packages/giada/ChangeLog
* Sat Sep  5 2015 avvissu@yandex.ru
- Update to 0.10.1:
  * see: /usr/share/doc/packages/giada/ChangeLog
- Del -Wno-parentheses to build with gcc5 (fixed in upstream)
* Mon Jul 20 2015 avvissu@yandex.ru
- Update to 0.10.0:
  * MIDI lightning output
  * other minor fixes
* Thu Jun 25 2015 avvissu@yandex.ru
- Update to 0.9.6:
  * see: /usr/share/doc/packages/giada/ChangeLog
- Remove patches:
  * giada-remove_build_timestamps.patch (use sed)
  * giada-add_missing_link_to_Xinerama.patch (fix to upstream)
- Add new package: rtmidi-devel libpulse-devel
- Build with gcc5: disable check:-Wno-parentheses
- Fix files is compiled without RPM_OPT_FLAGS
- Remove giada.desktop: use %%%%suse_update_desktop_file
- Add %%%%icon_theme_cache_(post,postun)
- Spec file cleanup
* Tue May 29 2012 pascal.bleser@opensuse.org
- update to 0.4.10:
  - Ability to shift up an down VST plugins
  - Enhanced patch/conf architecture
  - Ability to edit a sample while playing
  - Mutex controls in VST processing
  - Lots of security issues fixed while changing pitch dynamically
  - Enhanced sub-window system
  - Several minor bugs fixed
- changes from 0.4.9:
  - No more mandatory inputs
  - Pitch value properly stored inside the patch
  - Several small VST host improvements
  - Enhanced window management
  - Ability to browse files while playing with main GUI (non-modal browser)
  - Improved error checking in KernelAudio
  - Wrong style for lower scrollbar in Browser (fixed)
  - Fixed compilation on 64 bit systems
  - Samplerate no longer hardcoded, auto-detected with JACK
  - Minor internal improvements and bugfixing
* Sat Apr 21 2012 pascal.bleser@opensuse.org
- initial version (0.4.8)
